
BEGIN {
    unless ($ENV{RELEASE_TESTING}) {
        require Test::More;
        Test::More::plan(
            skip_all => 'these tests are for release candidate testing');
    }
}

use strict;
use warnings;
use Test::More;

eval 'use Test::EOL';
plan skip_all => 'Test::EOL required' if $@;

#diag "skipping test" ;
#ok(1);
#done_testing;
#exit;

all_perl_files_ok({trailing_whitespace => 1});
